![Banner](https://rawcdn.githack.com/rlaphoenix/pydvdcss/dfea6bed42cf13cb9d5839ddc1c54f4efbc5ec5e/banner.png)

[![Linter: Ruff](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/ruff/main/assets/badge/v2.json)](https://github.com/astral-sh/ruff)
[![Dependency management: Poetry](https://img.shields.io/endpoint?url=https://python-poetry.org/badge/v0.json)](https://python-poetry.org/)
[![Python version](https://img.shields.io/pypi/pyversions/pydvdcss)](https://pypi.python.org/pypi/pydvdcss)
[![Release version](https://img.shields.io/pypi/v/pydvdcss)](https://pypi.python.org/pypi/pydvdcss)
[![DeepSource issues](https://deepsource.io/gh/rlaphoenix/pydvdcss.svg/?label=active+issues)](https://deepsource.io/gh/rlaphoenix/pydvdcss)
[![Build status](https://github.com/rlaphoenix/pydvdcss/actions/workflows/ci.yml/badge.svg)](https://github.com/rlaphoenix/pydvdcss/actions/workflows/ci.yml)
[![Docs status](https://readthedocs.org/projects/pydvdcss/badge/)](https://pydvdcss.readthedocs.io)

**pydvdcss** is a python wrapper for VideoLAN's [libdvdcss].

[libdvdcss] is a simple library designed for accessing DVDs like a block device without having to bother about the
decryption.

  [libdvdcss]: <https://www.videolan.org/developers/libdvdcss.html>

**Documentation**: https://pydvdcss.phoeniix.dev  
**License**: [GNU General Public License, Version 3.0](LICENSE)
